createRegimens: Create an oncology drug regimen table in a...

View source: R/CreateRegimens.R

createRegimensR Documentation

Create an oncology drug regimen table in a 'writeDatabaseSchema' database

Description

Creates treatment regimens

Usage

createRegimens(
  connectionDetails,
  cdmDatabaseSchema,
  writeDatabaseSchema,
  cohortTable,
  rawEventTable,
  regimenTable,
  regimenIngredientTable,
  vocabularyTable,
  cancerConceptId = 4115276,
  dateLagInput = 30,
  generateVocabTable = FALSE,
  generateRawEvents = FALSE,
  keepSteroids = FALSE,
  useHemoncToPullDrugs = FALSE,
  writeToEpisodeTable = FALSE,
  writeToEpisodeEventTable = FALSE,
  episodeTypeConceptId = 32545,
  episodeEventTableConceptId = 1147094
)

Arguments

keepSteroids

Boolean parameter if TRUE algorithm will look for steroids along other drugs

useHemoncToPullDrugs

Boolean parameter if TRUE algorithm will use HemOnc vocabulary as a source of ingredients otherwise - internal csv

writeToEpisodeTable

Boolean parameter if TRUE algorithm will delete form episode table with 'episodeTypeConceptId' and insert 'regimenIngredientTable' rows with 'episodeTypeConceptId'

writeToEpisodeEventTable

Boolean parameter if TRUE algorithm will delete form episode_event table with 'episodeEventTableConceptId' and insert 'regimenIngredientTable' rows with 'episodeEventTableConceptId'

Value

This function does not return a value. It is called for its side effect of creating a new SQL table called 'regimenIngredientTable' in 'writeDatabaseSchema'.


A1exanderAlexeyuk/OncologyRegimenFinder documentation built on Feb. 10, 2023, 10:11 a.m.